==> asm7090-2.1.0.tar.gz: asm7090/asmnums.h <==
/***********************************************************************
*
* asmnums.h - FP nums for the IBM 7090 assembler.
*
* Changes:
*   12/30/04   DGP   Original.
*	
***********************************************************************/

/*
** 1Enn single precision
*/

t_uint64 ptens[] =
{
#ifdef WIN32
   0201400000000I64, 0204500000000I64, 0207620000000I64, 0212764000000I64,
   0216470400000I64, 0221606500000I64, 0224750220000I64, 0230461132000I64,
   0233575360400I64, 0236734654500I64, 0242452013710I64, 0245564416672I64,
   0250721522451I64, 0254443023471I64, 0257553630410I64, 0262706576512I64,
   0266434157116I64, 0271543212741I64, 0274674055532I64, 0300425434430I64,
   0303532743536I64, 0306661534466I64, 0312417031702I64, 0315522640262I64,
   0320647410336I64, 0324410545213I64, 0327512676456I64, 0332635456171I64,
   0336402374714I64, 0341503074077I64, 0344623713116I64, 0347770675742I64,
   0353473426555I64, 0356612334311I64, 0361755023373I64, 0365464114135I64,
   0370601137164I64, 0373741367021I64, 0377454732313I64,
#else
   0201400000000ULL, 0204500000000ULL, 0207620000000ULL, 0212764000000ULL,
   0216470400000ULL, 0221606500000ULL, 0224750220000ULL, 0230461132000ULL,
   0233575360400ULL, 0236734654500ULL, 0242452013710ULL, 0245564416672ULL,
   0250721522451ULL, 0254443023471ULL, 0257553630410ULL, 0262706576512ULL,
   0266434157116ULL, 0271543212741ULL, 0274674055532ULL, 0300425434430ULL,
   0303532743536ULL, 0306661534466ULL, 0312417031702ULL, 0315522640262ULL,
   0320647410336ULL, 0324410545213ULL, 0327512676456ULL, 0332635456171ULL,
   0336402374714ULL, 0341503074077ULL, 0344623713116ULL, 0347770675742ULL,
   0353473426555ULL, 0356612334311ULL, 0361755023373ULL, 0365464114135ULL,
   0370601137164ULL, 0373741367021ULL, 0377454732313ULL,
#endif
};

/*
** 1E-nn single precision
*/

t_uint64 mtens[] =
{
#ifdef WIN32
   0175631463146I64, 0172507534122I64, 0167406111565I64, 0163643334273I64,
   0160517426542I64, 0155414336750I64, 0151655376247I64, 0146527461671I64,
   0143422701372I64, 0137667633766I64, 0134537657770I64, 0131431363140I64,
   0125702270232I64, 0122550223342I64, 0117440165750I64, 0113715126246I64,
   0110560736522I64, 0105447113564I64, 0101730171124I64, 0076571624103I64,
   0073456166403I64, 0067743444004I64, 0064602666320I64, 0061465370246I64,
   0055757132075I64, 0052614110061I64, 0047474723216I64, 0043773036660I64,
   0040625513700I64, 0035504411400I64, 0032403472631I64, 0026637304365I64,
   0023514235136I64, 0020411660745I64, 0014651264556I64, 0011524220445I64,
   0006420163521I64, 0002663437347I64,
#else
   0175631463146ULL, 0172507534122ULL, 0167406111565ULL, 0163643334273ULL,
   0160517426542ULL, 0155414336750ULL, 0151655376247ULL, 0146527461671ULL,
   0143422701372ULL, 0137667633766ULL, 0134537657770ULL, 0131431363140ULL,
   0125702270232ULL, 0122550223342ULL, 0117440165750ULL, 0113715126246ULL,
   0110560736522ULL, 0105447113564ULL, 0101730171124ULL, 0076571624103ULL,
   0073456166403ULL, 0067743444004ULL, 0064602666320ULL, 0061465370246ULL,
   0055757132075ULL, 0052614110061ULL, 0047474723216ULL, 0043773036660ULL,
   0040625513700ULL, 0035504411400ULL, 0032403472631ULL, 0026637304365ULL,
   0023514235136ULL, 0020411660745ULL, 0014651264556ULL, 0011524220445ULL,
   0006420163521ULL, 0002663437347ULL,
#endif
};

/*
** 1Enn double precision
*/

t_uint64 dptens[] =
{
#ifdef WIN32
   0201400000000000000000I64, 0204500000000000000000I64,
   0207620000000000000000I64, 0212764000000000000000I64,
   0216470400000000000000I64, 0221606500000000000000I64,
   0224750220000000000000I64, 0230461132000000000000I64,
   0233575360400000000000I64, 0236734654500000000000I64,
   0242452013710000000000I64, 0245564416672000000000I64,
   0250721522450400000000I64, 0254443023471240000000I64,
   0257553630407510000000I64, 0262706576511432000000I64,
   0266434157115760200000I64, 0271543212741354240000I64,
   0274674055531647310000I64, 0300425434430110475000I64,
   0303532743536132614200I64, 0306661534465561357240I64,
   0312417031701446725444I64, 0315522640261760512755I64,
   0320647410336354635550I64, 0324410545213024002441I64,
   0327512676455631003151I64, 0332635456171177204004I64,
   0336402374713617422402I64, 0341503074076563327103I64,
   0344623713116320214724I64, 0347770675742004260111I64,
   0353473426555202556055I64, 0356612334310443311471I64,
   0361755023372554174007I64, 0365464114134543515404I64,
   0370601137163567440705I64, 0373741367020653551067I64,
   0377454732312413241542I64,
#else
   0201400000000000000000ULL, 0204500000000000000000ULL,
   0207620000000000000000ULL, 0212764000000000000000ULL,
   0216470400000000000000ULL, 0221606500000000000000ULL,
   0224750220000000000000ULL, 0230461132000000000000ULL,
   0233575360400000000000ULL, 0236734654500000000000ULL,
   0242452013710000000000ULL, 0245564416672000000000ULL,
   0250721522450400000000ULL, 0254443023471240000000ULL,
   0257553630407510000000ULL, 0262706576511432000000ULL,
   0266434157115760200000ULL, 0271543212741354240000ULL,
   0274674055531647310000ULL, 0300425434430110475000ULL,
   0303532743536132614200ULL, 0306661534465561357240ULL,
   0312417031701446725444ULL, 0315522640261760512755ULL,
   0320647410336354635550ULL, 0324410545213024002441ULL,
   0327512676455631003151ULL, 0332635456171177204004ULL,
   0336402374713617422402ULL, 0341503074076563327103ULL,
   0344623713116320214724ULL, 0347770675742004260111ULL,
   0353473426555202556055ULL, 0356612334310443311471ULL,
   0361755023372554174007ULL, 0365464114134543515404ULL,
   0370601137163567440705ULL, 0373741367020653551067ULL,
   0377454732312413241542ULL,
#endif
};

/*
** 1E-nn double precision
*/

t_uint64 dmtens[] =
{
#ifdef WIN32
   0175631463146314631463I64, 0172507534121727024366I64,
   0167406111564570651770I64, 0163643334272616103131I64,
   0160517426542161550741I64, 0155414336750132755432I64,
   0151655376246536257221I64, 0146527461670430214164I64,
   0143422701372023326451I64, 0137667633766353675565I64,
   0134537657770274544453I64, 0131431363140226752042I64,
   0125702270232044566404I64, 0122550223341520453466I64,
   0117440165747563526053I64, 0113715126245754211570I64,
   0110560736521443324455I64, 0105447113564351103527I64,
   0101730171123733322530I64, 0076571624103111102107I64,
   0073456166402407233237I64, 0067743444004013536713I64,
   0064602666320011262243I64, 0061465370246324216517I64,
   0055757132075355175661I64, 0052614110061127313047I64,
   0047474723215571074040I64, 0043773036657450140063I64,
   0040625513677523263217I64, 0035504411377565702477I64,
   0032403472631000000000I64, 0026637304365000000000I64,
   0023514235136000000000I64, 0020411660745000000000I64,
   0014651264556000000000I64, 0011524220445000000000I64,
   0006420163521000000000I64, 0002663437347000000000I64,
#else
   0175631463146314631463ULL, 0172507534121727024366ULL,
   0167406111564570651770ULL, 0163643334272616103131ULL,
   0160517426542161550741ULL, 0155414336750132755432ULL,
   0151655376246536257221ULL, 0146527461670430214164ULL,
   0143422701372023326451ULL, 0137667633766353675565ULL,
   0134537657770274544453ULL, 0131431363140226752042ULL,
   0125702270232044566404ULL, 0122550223341520453466ULL,
   0117440165747563526053ULL, 0113715126245754211570ULL,
   0110560736521443324455ULL, 0105447113564351103527ULL,
   0101730171123733322530ULL, 0076571624103111102107ULL,
   0073456166402407233237ULL, 0067743444004013536713ULL,
   0064602666320011262243ULL, 0061465370246324216517ULL,
   0055757132075355175661ULL, 0052614110061127313047ULL,
   0047474723215571074040ULL, 0043773036657450140063ULL,
   0040625513677523263217ULL, 0035504411377565702477ULL,
   0032403472631000000000ULL, 0026637304365000000000ULL,
   0023514235136000000000ULL, 0020411660745000000000ULL,
   0014651264556000000000ULL, 0011524220445000000000ULL,
   0006420163521000000000ULL, 0002663437347000000000ULL,
#endif
};

==> asm7090-2.3.2.tar.gz: asm7090/asmnums.h <==
/***********************************************************************
*
* asmnums.h - FP nums for the IBM 7090 assembler.
*
* Changes:
*   12/30/04   DGP   Original.
*   12/15/05   RMS   MINGW changes.
*	
***********************************************************************/

/*
** 1Enn single precision
*/

t_uint64 ptens[] =
{
#if defined(WIN32) && !defined(MINGW)
   0201400000000I64, 0204500000000I64, 0207620000000I64, 0212764000000I64,
   0216470400000I64, 0221606500000I64, 0224750220000I64, 0230461132000I64,
   0233575360400I64, 0236734654500I64, 0242452013710I64, 0245564416672I64,
   0250721522451I64, 0254443023471I64, 0257553630410I64, 0262706576512I64,
   0266434157116I64, 0271543212741I64, 0274674055532I64, 0300425434430I64,
   0303532743536I64, 0306661534466I64, 0312417031702I64, 0315522640262I64,
   0320647410336I64, 0324410545213I64, 0327512676456I64, 0332635456171I64,
   0336402374714I64, 0341503074077I64, 0344623713116I64, 0347770675742I64,
   0353473426555I64, 0356612334311I64, 0361755023373I64, 0365464114135I64,
   0370601137164I64, 0373741367021I64, 0377454732313I64,
#else
   0201400000000ULL, 0204500000000ULL, 0207620000000ULL, 0212764000000ULL,
   0216470400000ULL, 0221606500000ULL, 0224750220000ULL, 0230461132000ULL,
   0233575360400ULL, 0236734654500ULL, 0242452013710ULL, 0245564416672ULL,
   0250721522451ULL, 0254443023471ULL, 0257553630410ULL, 0262706576512ULL,
   0266434157116ULL, 0271543212741ULL, 0274674055532ULL, 0300425434430ULL,
   0303532743536ULL, 0306661534466ULL, 0312417031702ULL, 0315522640262ULL,
   0320647410336ULL, 0324410545213ULL, 0327512676456ULL, 0332635456171ULL,
   0336402374714ULL, 0341503074077ULL, 0344623713116ULL, 0347770675742ULL,
   0353473426555ULL, 0356612334311ULL, 0361755023373ULL, 0365464114135ULL,
   0370601137164ULL, 0373741367021ULL, 0377454732313ULL,
#endif
};

/*
** 1E-nn single precision
*/

t_uint64 mtens[] =
{
#if defined(WIN32) && !defined(MINGW)
   0175631463146I64, 0172507534122I64, 0167406111565I64, 0163643334273I64,
   0160517426542I64, 0155414336750I64, 0151655376247I64, 0146527461671I64,
   0143422701372I64, 0137667633766I64, 0134537657770I64, 0131431363140I64,
   0125702270232I64, 0122550223342I64, 0117440165750I64, 0113715126246I64,
   0110560736522I64, 0105447113564I64, 0101730171124I64, 0076571624103I64,
   0073456166403I64, 0067743444004I64, 0064602666320I64, 0061465370246I64,
   0055757132075I64, 0052614110061I64, 0047474723216I64, 0043773036660I64,
   0040625513700I64, 0035504411400I64, 0032403472631I64, 0026637304365I64,
   0023514235136I64, 0020411660745I64, 0014651264556I64, 0011524220445I64,
   0006420163521I64, 0002663437347I64,
#else
   0175631463146ULL, 0172507534122ULL, 0167406111565ULL, 0163643334273ULL,
   0160517426542ULL, 0155414336750ULL, 0151655376247ULL, 0146527461671ULL,
   0143422701372ULL, 0137667633766ULL, 0134537657770ULL, 0131431363140ULL,
   0125702270232ULL, 0122550223342ULL, 0117440165750ULL, 0113715126246ULL,
   0110560736522ULL, 0105447113564ULL, 0101730171124ULL, 0076571624103ULL,
   0073456166403ULL, 0067743444004ULL, 0064602666320ULL, 0061465370246ULL,
   0055757132075ULL, 0052614110061ULL, 0047474723216ULL, 0043773036660ULL,
   0040625513700ULL, 0035504411400ULL, 0032403472631ULL, 0026637304365ULL,
   0023514235136ULL, 0020411660745ULL, 0014651264556ULL, 0011524220445ULL,
   0006420163521ULL, 0002663437347ULL,
#endif
};

/*
** 1Enn double precision
*/

t_uint64 dptens[] =
{
#if defined(WIN32) && !defined(MINGW)
   0201400000000000000000I64, 0204500000000000000000I64,
   0207620000000000000000I64, 0212764000000000000000I64,
   0216470400000000000000I64, 0221606500000000000000I64,
   0224750220000000000000I64, 0230461132000000000000I64,
   0233575360400000000000I64, 0236734654500000000000I64,
   0242452013710000000000I64, 0245564416672000000000I64,
   0250721522450400000000I64, 0254443023471240000000I64,
   0257553630407510000000I64, 0262706576511432000000I64,
   0266434157115760200000I64, 0271543212741354240000I64,
   0274674055531647310000I64, 0300425434430110475000I64,
   0303532743536132614200I64, 0306661534465561357240I64,
   0312417031701446725444I64, 0315522640261760512755I64,
   0320647410336354635550I64, 0324410545213024002441I64,
   0327512676455631003151I64, 0332635456171177204004I64,
   0336402374713617422402I64, 0341503074076563327103I64,
   0344623713116320214724I64, 0347770675742004260111I64,
   0353473426555202556055I64, 0356612334310443311471I64,
   0361755023372554174007I64, 0365464114134543515404I64,
   0370601137163567440705I64, 0373741367020653551067I64,
   0377454732312413241542I64,
#else
   0201400000000000000000ULL, 0204500000000000000000ULL,
   0207620000000000000000ULL, 0212764000000000000000ULL,
   0216470400000000000000ULL, 0221606500000000000000ULL,
   0224750220000000000000ULL, 0230461132000000000000ULL,
   0233575360400000000000ULL, 0236734654500000000000ULL,
   0242452013710000000000ULL, 0245564416672000000000ULL,
   0250721522450400000000ULL, 0254443023471240000000ULL,
   0257553630407510000000ULL, 0262706576511432000000ULL,
   0266434157115760200000ULL, 0271543212741354240000ULL,
   0274674055531647310000ULL, 0300425434430110475000ULL,
   0303532743536132614200ULL, 0306661534465561357240ULL,
   0312417031701446725444ULL, 0315522640261760512755ULL,
   0320647410336354635550ULL, 0324410545213024002441ULL,
   0327512676455631003151ULL, 0332635456171177204004ULL,
   0336402374713617422402ULL, 0341503074076563327103ULL,
   0344623713116320214724ULL, 0347770675742004260111ULL,
   0353473426555202556055ULL, 0356612334310443311471ULL,
   0361755023372554174007ULL, 0365464114134543515404ULL,
   0370601137163567440705ULL, 0373741367020653551067ULL,
   0377454732312413241542ULL,
#endif
};

/*
** 1E-nn double precision
*/

t_uint64 dmtens[] =
{
#if defined(WIN32) && !defined(MINGW)
   0175631463146314631463I64, 0172507534121727024366I64,
   0167406111564570651770I64, 0163643334272616103131I64,
   0160517426542161550741I64, 0155414336750132755432I64,
   0151655376246536257221I64, 0146527461670430214164I64,
   0143422701372023326451I64, 0137667633766353675565I64,
   0134537657770274544453I64, 0131431363140226752042I64,
   0125702270232044566404I64, 0122550223341520453466I64,
   0117440165747563526053I64, 0113715126245754211570I64,
   0110560736521443324455I64, 0105447113564351103527I64,
   0101730171123733322530I64, 0076571624103111102107I64,
   0073456166402407233237I64, 0067743444004013536713I64,
   0064602666320011262243I64, 0061465370246324216517I64,
   0055757132075355175661I64, 0052614110061127313047I64,
   0047474723215571074040I64, 0043773036657450140063I64,
   0040625513677523263217I64, 0035504411377565702477I64,
   0032403472631000000000I64, 0026637304365000000000I64,
   0023514235136000000000I64, 0020411660745000000000I64,
   0014651264556000000000I64, 0011524220445000000000I64,
   0006420163521000000000I64, 0002663437347000000000I64,
#else
   0175631463146314631463ULL, 0172507534121727024366ULL,
   0167406111564570651770ULL, 0163643334272616103131ULL,
   0160517426542161550741ULL, 0155414336750132755432ULL,
   0151655376246536257221ULL, 0146527461670430214164ULL,
   0143422701372023326451ULL, 0137667633766353675565ULL,
   0134537657770274544453ULL, 0131431363140226752042ULL,
   0125702270232044566404ULL, 0122550223341520453466ULL,
   0117440165747563526053ULL, 0113715126245754211570ULL,
   0110560736521443324455ULL, 0105447113564351103527ULL,
   0101730171123733322530ULL, 0076571624103111102107ULL,
   0073456166402407233237ULL, 0067743444004013536713ULL,
   0064602666320011262243ULL, 0061465370246324216517ULL,
   0055757132075355175661ULL, 0052614110061127313047ULL,
   0047474723215571074040ULL, 0043773036657450140063ULL,
   0040625513677523263217ULL, 0035504411377565702477ULL,
   0032403472631000000000ULL, 0026637304365000000000ULL,
   0023514235136000000000ULL, 0020411660745000000000ULL,
   0014651264556000000000ULL, 0011524220445000000000ULL,
   0006420163521000000000ULL, 0002663437347000000000ULL,
#endif
};
